/***************************************************************************************************/
/*script in Sql, generate by SdmCreateScript 2020(by Qihang Feng, QF255001@TERADATA.COM)     */
/*VERSION 01.10 revised on 2020-08-25                                                              */
/*Brilliance stems from wisdoms.                                                                   */
/*************Head Section**************************************************************************/
/*Script Use: Periodically load data to :cust_call_record_info(ccc客户通话记录信息)             */
/*Create Date:2024-09-23 15:50:38                                                                  */
/*SDM Developed By: dev                                                                            */
/*SDM Developed Date: 2024-09-19                                                                   */
/*SDM Checked By: dev                                                                              */
/*SDM Checked Date: 2024-09-23                                                                     */
/*Script Developed By: dev                                                                         */
/*Script Checked By: dev                                                                           */
/*Source table 1: :COMMDB.select distinct on (tel) * from p30_common.d_ccc_cust_info               */
/*Source table 2: :PDMDB.t01_udesk_record                                                          */
/*Source table 3: :COMMDB.cust_call_ccc_record                                                     */
/*Job Type: Inbound transform (Tier 1 to Tier 2)                                                   */
/*Target Table:cust_call_record_info                                                               */
/*ETL Job Name:cust_call_record_info                                                               */
/*ETL Frequency:None                                                                               */
/*ETL Policy:F1                                                                                    */
/********************************************************************************************/
/*******Main Section**************************************************************************/
\set ON_ERROR_STOP on
\set AUTOCOMMIT on
\timing on



/*创建临时表加载当前数据                                                                           */
CREATE TEMPORARY TABLE cust_call_record_info_agi_CUR_I 
 ( LIKE :MARTDB.cust_call_record_info)
ON COMMIT PRESERVE ROWS;


/*****************************************************************************************************/
/* GROUP 1:Source Table:cust_call_ccc_record**********************************************************/
/*****************************************************************************************************/

INSERT INTO cust_call_record_info_agi_CUR_I (
            call_id                                 /*通话编号*/
           ,call_channel                            /*通话渠道*/
           ,start_time                              /*开始时间*/
           ,bridge_duration                         /*持续时间*/
           ,call_qname                              /*通话队列名称*/
           ,service_group                           /*服务组*/
           ,customer_number                         /*客户电话*/
           ,name                                    /*姓名*/
           ,email                                   /*邮箱*/
           ,company                                 /*公司*/
        )
SELECT
         COALESCE(TRIM(p0.call_id),'')                             /*call_id*/
        ,'Smart CCC'                                               /*call_channel*/
        ,COALESCE(p0.start_time,TO_TIMESTAMP(:NULLDATE,'YYYYMMDD'))        /*start_time*/
        ,COALESCE(CAST(p0.bridge_duration AS numeric (24,3)),0)        /*bridge_duration*/
        ,COALESCE(TRIM(p0.call_qname),'')                          /*call_qname*/
        ,case when p0.call_qname  in ('选型报价','选型报价统计','TW销售服务') then '产品报价'
      when p0.call_qname  in ('售前技术','售后技术','技术支持统计') then '技术支持'
      when p0.call_qname  in ('保内维修','保外维修与计量','维修计量统计') then '维修与校准'
      when p0.call_qname  in ('其他咨询','其他支持统计') then '其他'
      when p0.call_qname  in ('') then ''
      else '其他' end        /*service_group*/
        ,COALESCE(TRIM(p0.customer_number),'')                     /*customer_number*/
        ,coalesce(p1."name",'无')                                   /*name*/
        ,coalesce(p1.email,'')                                     /*email*/
        ,coalesce(p1.company,'')                                   /*company*/
        
FROM :COMMDB.cust_call_ccc_record  p0
LEFT JOIN (select distinct on (tel) * from p30_common.d_ccc_cust_info) p1
        ON p0.customer_number =p1.tel
where p0.hotline_name in ('400呼入','Inbound','SG-TSC')

;



/*****************************************************************************************************/
/* GROUP 2:Source Table:t01_udesk_record**************************************************************/
/*****************************************************************************************************/

INSERT INTO cust_call_record_info_agi_CUR_I (
            call_id                                 /*通话编号*/
           ,call_channel                            /*通话渠道*/
           ,start_time                              /*开始时间*/
           ,bridge_duration                         /*持续时间*/
           ,call_qname                              /*通话队列名称*/
           ,service_group                           /*服务组*/
           ,customer_number                         /*客户电话*/
           ,name                                    /*姓名*/
           ,email                                   /*邮箱*/
           ,company                                 /*公司*/
        )
SELECT
         COALESCE(TRIM(p0.call_id),'')                             /*call_id*/
        ,'Udesk'                                                   /*call_channel*/
        ,p0.record_time                                            /*start_time*/
        ,extract (epoch from duration::time)                       /*bridge_duration*/
        ,udesk_source                                              /*call_qname*/
        ,case when udesk_source ='队列: IAM' then '产品报价'
when udesk_source in ('队列: TSC-KEI','队列: TSC-TEK') then '技术支持'
when udesk_source ='队列: SSO-TEK' then '维修与校准'
when  udesk_source ='' then ''
else '其他' end        /*service_group*/
        ,COALESCE(TRIM(p0.mobile_phone),'')                        /*customer_number*/
        ,cust                                                      /*name*/
        ,''                                                        /*email*/
        ,company_name                                              /*company*/
        
FROM :PDMDB.t01_udesk_record  p0
where p0.type = '呼入' and p0.relay_number not like '%MKT%' and p0.relay_number not like '%Fluke%' and record_time ::date >='2024-01-01'
and udesk_source in ('队列: IAM','队列: SSO-TEK','队列: TSC-KEI','队列: TSC-TEK')
and udesk_source in ('队列: IAM','队列: SSO-TEK','队列: TSC-KEI','队列: TSC-TEK');

;



/*从目标表中删除所有数据 cust_call_record_info(ccc客户通话记录信息)                                 */
DELETE FROM :MARTDB.cust_call_record_info 
;


/*将新增数据插入到目标表                                                                           */
;INSERT INTO :MARTDB.cust_call_record_info (
             call_id                                                   /*通话编号*/
            ,call_channel                                              /*通话渠道*/
            ,start_time                                                /*开始时间*/
            ,bridge_duration                                           /*持续时间*/
            ,call_qname                                                /*通话队列名称*/
            ,service_group                                             /*服务组*/
            ,customer_number                                           /*客户电话*/
            ,name                                                      /*姓名*/
            ,email                                                     /*邮箱*/
            ,company                                                   /*公司*/
            
    )
    SELECT
             P1.call_id                                                   /*通话编号*/
            ,P1.call_channel                                              /*通话渠道*/
            ,P1.start_time                                                /*开始时间*/
            ,P1.bridge_duration                                           /*持续时间*/
            ,P1.call_qname                                                /*通话队列名称*/
            ,P1.service_group                                             /*服务组*/
            ,P1.customer_number                                           /*客户电话*/
            ,P1.name                                                      /*姓名*/
            ,P1.email                                                     /*邮箱*/
            ,P1.company                                                   /*公司*/
            
    FROM cust_call_record_info_agi_CUR_I P1
 
;
/*****程序结束退出                                               */
\q

